@@ -1,6 +1,6 @@
 from requests import get
 from json import loads
-from say import *
+from PLManfred.say import *
 
 def temp(citi):
         url = 'https://danepubliczne.imgw.pl/api/data/synop'
